# Release Notes

### March 2025: version 0.5.7

Just a single bug fix.

* Issue #1: Fix for panic when trying to construct 128 bit ints. Thanks to @mgorny and @FineFindus. 

### March 2025: version 0.5.6

First version used as a dependency for bitstring. This increases the visibility of tibs quite a lot even though
it isn't yet turned on by default in bitstring.

I shall be better at making release notes from now on!

### November 2025 - February 2026; versions 0.1.0 - 0.5.0.

From the first release with the `Tibs` and `Mutibs` classes to the first beta
with a completed initial API.

### November 2025; version 0.0.1.

#### Project start

The original version is a cut-down and rebranded version of bitformat.

Its main job is to reserve the name on PyPI.

